@@ -928,6 +928,7 @@ as_app_validate_license (const gchar *license_text, GError **error)
 	for (i = 0; licenses[i] != NULL; i++) {
 		if (g_strcmp0 (licenses[i], "&") == 0 ||
 		    g_strcmp0 (licenses[i], "|") == 0 ||
+		    g_strcmp0 (licenses[i], "+") == 0 ||
 		    g_strcmp0 (licenses[i], "(") == 0 ||
 		    g_strcmp0 (licenses[i], ")") == 0)
 			continue;
@@ -951,20 +952,12 @@ as_app_validate_is_content_license_id (const gchar *license_id)
 		return TRUE;
 	if (g_strcmp0 (license_id, "@CC-BY-3.0") == 0)
 		return TRUE;
-	if (g_strcmp0 (license_id, "@CC-BY-3.0+") == 0)
-		return TRUE;
 	if (g_strcmp0 (license_id, "@CC-BY-4.0") == 0)
 		return TRUE;
-	if (g_strcmp0 (license_id, "@CC-BY-4.0+") == 0)
-		return TRUE;
 	if (g_strcmp0 (license_id, "@CC-BY-SA-3.0") == 0)
 		return TRUE;
-	if (g_strcmp0 (license_id, "@CC-BY-SA-3.0+") == 0)
-		return TRUE;
 	if (g_strcmp0 (license_id, "@CC-BY-SA-4.0") == 0)
 		return TRUE;
-	if (g_strcmp0 (license_id, "@CC-BY-SA-4.0+") == 0)
-		return TRUE;
 	if (g_strcmp0 (license_id, "@GFDL-1.1") == 0)
 		return TRUE;
 	if (g_strcmp0 (license_id, "@GFDL-1.2") == 0)
@@ -977,6 +970,8 @@ as_app_validate_is_content_license_id (const gchar *license_id)
 		return TRUE;
 	if (g_strcmp0 (license_id, "|") == 0)
 		return TRUE;
+	if (g_strcmp0 (license_id, "+") == 0)
+		return TRUE;
 	return FALSE;
 }
 
@@ -1228,10 +1223,11 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 
 	/* appdata */
 	if (as_app_get_icon_default (app) != NULL &&
-	    as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_APPDATA) {
+	    as_app_get_source_kind (app) == AS_APP_SOURCE_KIND_APPDATA &&
+	    as_app_get_kind (app) == AS_APP_KIND_DESKTOP) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_TAG_INVALID,
-				     "<icon> not allowed in appdata");
+				     "<icon> not allowed in desktop appdata");
 	}
 
 	/* extends */
